@@ -27,5 +27,7 @@ static const struct mapping mappings[] = {
     {.extension = ".txt",    .filetype = '0'},
     {.extension = ".map",    .filetype = '1'},
     {.extension = ".jpg",    .filetype = 'I'},
-    {.extension = ".jpeg",    .filetype = 'I'}
+    {.extension = ".jpeg",    .filetype = 'I'},
+    {.extension = ".png",    .filetype = 'I'},
+    {.extension = ".JPG",    .filetype = 'I'}
 };
