@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2024 Daniel Wilkins <tekk@linuxmail.org>
+ * Copyright (c) 2019-2025 Daniel Wilkins <tekk@linuxmail.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -319,31 +319,51 @@ void list(int fd, char *path) {
     }
 }
 
+int substr(char *needle, char *haystack) {
+    size_t haystack_l = strlen(haystack);
+    char *tn = needle;
+
+    for (size_t i = 0; i < haystack_l; i++) {
+        if (haystack[i] == *tn) {
+            tn++;
+            if (*tn == '\0') {
+                return 1;
+            }
+        } else {tn = needle;}
+    }
+    return 0;
+}
+
 void handle_connection(struct connection *conn) {
     char selector[1024] = {0};
-
+    size_t off = 0;
+    size_t lastread = 0;
+    do {
+	lastread = read(conn->fd, selector + off, 1022 - off);
+	off += lastread;
+    }  while (lastread > 0 && !substr("\r\n", selector));
     emit(DEBUG, "Connection opened");
-    if (read(conn->fd, selector, 1022)) {
-        int len = strlen(selector);
-        printf("%d\n", len);
-
-        for (int i = 0; i < len; i++) {
-            printf("%x", (unsigned char)selector[i]);
-        }
-        printf("\n");
-        
-
-        emit(DEBUG, selector);
-        
-        if (len > 2 && selector[len-2] == '\r' && selector[len-1] == '\n') {
-            selector[len-2] = '\0';
-            list(conn->fd, selector);
-        } else if (len == 2 && selector[len-2] == '\r' && selector[len-1] == '\n') {
-            list(conn->fd, "/");
-            
-        }
-
+    if (off == 0) {
+	return;
     }
+    int len = strlen(selector);
+    printf("%d\n", len);
+
+    for (int i = 0; i < len; i++) {
+        printf("0x%x,", (unsigned char)selector[i]);
+    }
+    printf("\n");
+        
+
+    emit(DEBUG, selector);
+        
+    if (len > 2 && selector[len-2] == '\r' && selector[len-1] == '\n') {
+       selector[len-2] = '\0';
+        list(conn->fd, selector);
+    } else if (len == 2 && selector[len-2] == '\r' && selector[len-1] == '\n') {
+        list(conn->fd, "/");
+    }
+
     close(conn->fd);
 }
 
